@@ -28,12 +28,15 @@ from .shortcuts.utils import disable_analytics_warnings
 # To distinguish between external and internal packages
 try:
     from .shortcuts.nordea import get_nordea_analytics_client  # type: ignore
+    from .shortcuts.nordea import get_nordea_analytics_test_client  # type: ignore # noqa: E401
 except (NameError, ModuleNotFoundError):
     from .shortcuts.open_banking import get_nordea_analytics_client  # type: ignore
+    from .shortcuts.open_banking import get_nordea_analytics_test_client  # type: ignore # noqa: F401
 
-__version__ = "1.2.5"
+__version__ = "1.2.6"
 __all__ = [
     "get_nordea_analytics_client",
+    "get_nordea_analytics_test_client",
     "disable_analytics_warnings",
     "AmortisationType",
     "AssetType",
