@@ -21,6 +21,7 @@ from nordea_analytics.nalib.util import (
     float_to_tenor_string,
     get_config,
 )
+from nordea_analytics.nalib.util import get_keyfigure_key
 from nordea_analytics.nalib.value_retriever import ValueRetriever
 
 config = get_config()
@@ -41,7 +42,15 @@ class BondKeyFigureCalculator(ValueRetriever):
             List[Union[str, CalculatedBondKeyFigureName]],
         ],
         calc_date: datetime,
-        curves: Optional[Union[List[str], str, CurveName, List[CurveName]]] = None,
+        curves: Optional[
+            Union[
+                str,
+                CurveName,
+                List[str],
+                List[CurveName],
+                List[Union[str, CurveName]],
+            ]
+        ] = None,
         rates_shifts: Optional[Union[List[str], str]] = None,
         pp_speed: Optional[float] = None,
         price: Optional[float] = None,
@@ -77,17 +86,40 @@ class BondKeyFigureCalculator(ValueRetriever):
         """
         super(BondKeyFigureCalculator, self).__init__(client)
         self._client = client
-        _keyfigures: List = keyfigures if type(keyfigures) == list else [keyfigures]
+        _keyfigures: List = keyfigures if isinstance(keyfigures, list) else [keyfigures]
         self.keyfigures = [
             convert_to_variable_string(keyfigure, CalculatedBondKeyFigureName)
+            if isinstance(keyfigure, CalculatedBondKeyFigureName)
+            else keyfigure.lower()
             for keyfigure in _keyfigures
         ]
-        self.symbols = [symbols] if type(symbols) == str else symbols
+        self.symbols = symbols if isinstance(symbols, list) else [symbols]
         self.calc_date = calc_date
+        self.key_figures_original: Union[
+            List[str],
+            List[CalculatedBondKeyFigureName],
+            List[Union[str, CalculatedBondKeyFigureName]],
+        ] = (
+            keyfigures if isinstance(keyfigures, list) else [keyfigures]
+        )
+        self.curves_original: Union[
+            List[str], List[CurveName], List[Union[str, CurveName]], None
+        ] = (
+            curves
+            if isinstance(curves, list)
+            else [curves]
+            if isinstance(curves, str)
+            else None
+        )
 
-        _curves: Union[List[Union[str, ValueError]], None]
+        _curves: Union[List[str], None]
         if isinstance(curves, list):
-            _curves = [convert_to_variable_string(curve, CurveName) for curve in curves]
+            _curves = [
+                convert_to_variable_string(curve, CurveName)
+                if isinstance(curve, CurveName)
+                else curve
+                for curve in curves
+            ]
         elif curves is not None:
             # mypy doesn't know that curves in this line is never a list
             _curves = [convert_to_variable_string(curves, CurveName)]  # type: ignore
@@ -172,6 +204,20 @@ class BondKeyFigureCalculator(ValueRetriever):
 
         return request_dict
 
+    def get_curve_key(self, curve_name: str) -> str:
+        """Get curve key for dict."""
+        if (
+            self.curves_original is not None and curve_name in self.curves_original
+        ):  # True when curve is input as string
+            curve_key = curve_name
+        else:
+            try:
+                curve_key = CurveName(curve_name).name
+            except Exception:
+                curve_key = curve_name
+
+        return curve_key
+
     def to_dict(self) -> Dict:
         """Reformat the json response to a dictionary."""
         _dict: Dict[Any, Any] = {}
@@ -187,7 +233,7 @@ class BondKeyFigureCalculator(ValueRetriever):
         for key_figure in bond_data:
             if key_figure != "price" and key_figure in self.keyfigures:
                 for curve_data in bond_data[key_figure]["values"]:
-                    _data_dict = {}
+                    _data_dict: Dict[Any, Any] = {}
                     if key_figure == "bpvladder":
                         ladder_dict = {
                             float_to_tenor_string(
@@ -196,38 +242,59 @@ class BondKeyFigureCalculator(ValueRetriever):
                             for ladder in curve_data["ladder"]
                         }
                         _data_dict[
-                            CalculatedBondKeyFigureName(key_figure).name
+                            get_keyfigure_key(
+                                key_figure,
+                                self.key_figures_original,
+                                CalculatedBondKeyFigureName.__name__,
+                            )
                         ] = ladder_dict
                     elif key_figure == "expectedcashflow":
                         cashflow_dict = {
-                            cashflows["key"]: convert_to_float_if_float(
-                                cashflows["value"]
-                            )
-                            for cashflows in curve_data["cashflows"]
+                            datetime.strptime(
+                                cashflow["payment_date"], "%Y-%m-%d"
+                            ).date(): {
+                                "interest": cashflow["interest"],
+                                "principal": cashflow["principal"],
+                            }
+                            for cashflow in curve_data["cashflows"]
                         }
                         _data_dict[
-                            CalculatedBondKeyFigureName(key_figure).name
+                            get_keyfigure_key(
+                                key_figure,
+                                self.key_figures_original,
+                                CalculatedBondKeyFigureName.__name__,
+                            )
                         ] = cashflow_dict
                     else:
                         _data_dict[
-                            CalculatedBondKeyFigureName(key_figure).name
+                            get_keyfigure_key(
+                                key_figure,
+                                self.key_figures_original,
+                                CalculatedBondKeyFigureName.__name__,
+                            )
                         ] = convert_to_float_if_float(
                             curve_data["value"]
                         )  # type:ignore
-                    if curve_data["key"] in _dict_bond.keys():
-                        _dict_bond[curve_data["key"]].update(_data_dict)
+
+                    curve_key = self.get_curve_key(curve_data["key"])
+                    if curve_key in _dict_bond.keys():
+                        _dict_bond[curve_key].update(_data_dict)
                     else:
-                        _dict_bond[curve_data["key"]] = _data_dict
-        if (
-            _dict_bond == {}
-        ):  # This would be the case if only Price would be selected as key figure
-            for curve_data in bond_data["bpv"]["values"]:
-                _dict_bond[curve_data["key"]] = {}
+                        _dict_bond[curve_key] = _data_dict
+
+        # This would be the case if only Price would be selected as key figure
+        # If not, price has no curve to be inserted into
+        if _dict_bond == {}:
+            _dict_bond["No curve found"] = {}
 
         if "price" in bond_data and "price" in self.keyfigures:
             for curve in _dict_bond:
                 _dict_bond[curve][
-                    CalculatedBondKeyFigureName("price").name
+                    get_keyfigure_key(
+                        "price",
+                        self.key_figures_original,
+                        CalculatedBondKeyFigureName.__name__,
+                    )
                 ] = bond_data["price"]
 
         return _dict_bond
