@@ -89,7 +89,9 @@ class Curve(ValueRetriever):
         )
         self.forward_tenor = self.check_forward(forward_tenor)
 
-        self._data = self.get_curve()
+        result = self.get_curve()
+
+        self._data = self.format_curve_names(result, _curves)
 
     def get_curve(self) -> List:
         """Retrieves response with curve."""
@@ -104,6 +106,32 @@ class Curve(ValueRetriever):
 
         return json_response
 
+    def format_curve_names(
+        self,
+        data: List,
+        curves: Union[List[str], List[CurveName], List[Union[str, CurveName]]],
+    ) -> List:
+        """Formats curve names to be identical to curves input."""
+        curve_dict = {}
+        for curve_name in curves:
+            curve_name_string: Union[str, ValueError]
+            if type(curve_name) == CurveName:
+                curve_name_string = convert_to_variable_string(
+                    curve_name, CurveName
+                ).upper()
+            elif type(curve_name) == str:
+                curve_name_string = curve_name.upper()
+            curve_dict[curve_name_string] = (
+                curve_name.name if type(curve_name) == CurveName else curve_name
+            )
+
+        for curve_result in data:
+            curve_result["curve"]["curve_specification"]["name"] = curve_dict[
+                curve_result["curve"]["curve_specification"]["name"].upper()
+            ]
+
+        return data
+
     def check_forward(self, forward_tenor: Union[float, None]) -> Union[str, None]:
         """Check if forward tenor should be given as an argument.
 
